# Lucidium

[![PyPI version](https://badge.fury.io/py/lucidium.svg)](https://badge.fury.io/py/lucidium)
[![Python 3.10+](https://img.shields.io/badge/python-3.10+-blue.svg)](https://www.python.org/downloads/)

Experiments in neuro-symbolic reinforcement learning in the pursuit of developing agents/methods to aid in organic reasoning, inference, and logic.

## [Documentation](https://github.com/theokoles7/lucidium/blob/main/documentation/README.md)
* ### [Agents](./lucidium/agents/README.md)
* ### [Concepts](./lucidium/documentation/concepts/README.md)
* ### [Environments](./lucidium/environments/README.md)

## House-Keeping

* ### [Code of Conduct](./CODE_OF_CONDUCT.md)
* ### [Contributing](./CONTRIBUTING)
* ### [License](./LICENSE)